@@ -1,8 +1,10 @@
 import os
+
 from pymk import error
 
 
 class Dependency(object):
+
     """Base of all dependencys."""
     detailed = []
 
@@ -29,23 +31,50 @@ class Dependency(object):
 
     def _get_shape_color(self):
         if self.runned:
-            return 'red'
+            return 'darkgreen'
         else:
             return 'white'
 
+    def _get_text_color(self):
+        return 'black'
+
     def write_graph_detailed(self, datalog):
         if not self.name in self.detailed:
             self.detailed.append(self.name)
-            datalog.write('"%s" [fillcolor=%s,%s];\n' % (self.name, self._get_shape_color(), self.get_graph_details()))
+            datalog.write('"%s" [fillcolor=%s,fontcolor=%s,%s];\n' % (
+                self.name,
+                self._get_shape_color(),
+                self._get_text_color(),
+                self.get_graph_details())
+            )
 
 
-class FileChanged(Dependency):
+class FileDependency(Dependency):
+
+    def __init__(self, filenames):
+        def convert_filenames(filenames):
+            if type(filenames) in [str, unicode]:
+                return [filenames]
+            else:
+                return filenames
+        super(FileDependency, self).__init__()
+        self.filenames = convert_filenames(filenames)
+
+    @property
+    def name(self):
+        if len(self.filenames) == 1:
+            return self.filenames[0]
+        else:
+            return 'Many files'
+
+
+class FileChanged(FileDependency):
+
     """Dependency returns true if file provided was changed. If task argument is
     provided, then run that task if it should be done."""
 
-    def __init__(self, filename, task=None):
-        super(FileChanged, self).__init__()
-        self.filename = filename
+    def __init__(self, filenames, task=None):
+        super(FileChanged, self).__init__(filenames)
         self.task = task
 
     def do_test(self, task, dependency_force=False):
@@ -53,7 +82,7 @@ class FileChanged(Dependency):
             if task is None:
                 return
             if task.output_file is None:
-                raise error.TaskMustHaveOutputFile(task.name())
+                raise error.TaskMustHaveOutputFile(task.getName())
 
         def compare_mtime(first, second):
             if os.path.getmtime(first) > os.path.getmtime(second):
@@ -67,7 +96,10 @@ class FileChanged(Dependency):
 
         def check_dependent_file():
             try:
-                return compare_mtime(self.filename, task.output_file)
+                result = False
+                for filename in self.filenames:
+                    result |= compare_mtime(filename, task.output_file)
+                return result
             except OSError:
                 return make_dependent_file()
         #-----------------------------------------------------------------------
@@ -80,51 +112,44 @@ class FileChanged(Dependency):
         if os.path.exists(task.output_file):
             return check_dependent_file()
         else:
-            if os.path.exists(self.filename):
-                return True
-            else:
-                raise error.CouldNotCreateFile(self.filename)
+            for filename in self.filenames:
+                if not os.path.exists(filename):
+                    raise error.CouldNotCreateFile(filename)
+            return True
 
     # === graph specyfic ===
     def extra(self):
         if self.runned:
-            return '[label="C",color="red"]'
+            return '[label="C",color="blue"]'
         else:
             return '[label="C"]'
 
-    @property
-    def name(self):
-        return self.filename
-
     def get_graph_details(self):
         return 'shape=hexagon,regular=1,style=filled,label="%s"' % (
             self.name.replace('/', '\\n')
         )
 
 
-class FileDoesNotExists(Dependency):
-    """Dependency returns ture if file does not exists."""
+class FileDoesNotExists(FileDependency):
 
-    def __init__(self, filename):
-        super(FileDoesNotExists, self).__init__()
-        self.filename = filename
+    """Dependency returns ture if file does not exists."""
 
     def do_test(self, task, dependency_force=False):
         if dependency_force:
             return True
-        return not os.path.exists(self.filename)
+
+        for filename in self.filenames:
+            if not os.path.exists(filename):
+                return True
+        return False
 
     # === graph specyfic ===
     def extra(self):
         if self.runned:
-            return '[label="NE",color="red"]'
+            return '[label="NE",color="blue"]'
         else:
             return '[label="NE"]'
 
-    @property
-    def name(self):
-        return self.filename
-
     def get_graph_details(self):
         return 'shape=triangle, regular=1,style=filled,label="%s"' % (
             self.name.replace('/', '\\n')
@@ -132,6 +157,7 @@ class FileDoesNotExists(Dependency):
 
 
 class AlwaysRebuild(Dependency):
+
     """Dependency will always make a task rebuild."""
 
     def __init__(self):
@@ -143,7 +169,7 @@ class AlwaysRebuild(Dependency):
     # === graph specyfic ===
     def extra(self):
         if self.runned:
-            return '[label="A",color="red"]'
+            return '[label="A",color="blue"]'
         else:
             return '[label="A"]'
 
@@ -152,7 +178,7 @@ class AlwaysRebuild(Dependency):
         return id(self)
 
     def get_graph_details(self):
-        return 'shape=diamond, regular=1,style=filled,fillcolor=red,label="Always\\nRebuild"'
+        return 'shape=diamond, regular=1,style=filled,fillcolor=blue,fontcolor=yellow,label="Always\\nRebuild"'
 
 
 class InnerDependency(Dependency):
@@ -164,14 +190,11 @@ class InnerDependency(Dependency):
     # === graph specyfic ===
     @property
     def name(self):
-        return self.parent.__name__
+        return self.parent.getName()
 
 
 class InnerFileExists(InnerDependency):
 
-    def __init__(self, parent):
-        super(InnerFileExists, self).__init__(parent)
-
     def do_test(self, task, dependency_force=False):
         if dependency_force:
             self.parent.run(True, True, True, task)
@@ -184,21 +207,18 @@ class InnerFileExists(InnerDependency):
                 self.parent.run(parent=task)
                 return True
         else:
-            raise error.TaskMustHaveOutputFile(self.parent.name())
+            raise error.TaskMustHaveOutputFile(self.parent.getName())
 
     # === graph specyfic ===
     def extra(self):
         if self.runned:
-            return '[label="E",color="red"]'
+            return '[label="E",color="blue"]'
         else:
             return '[label="E"]'
 
 
 class InnerFileChanged(InnerDependency):
 
-    def __init__(self, parent):
-        super(InnerFileChanged, self).__init__(parent)
-
     def do_test(self, task, dependency_force=False):
         if dependency_force:
             self.parent.run(True, True, True, parent=task)
@@ -208,6 +228,16 @@ class InnerFileChanged(InnerDependency):
     # === graph specyfic ===
     def extra(self):
         if self.runned:
-            return '[label="C",color="red"]'
+            return '[label="C",color="blue"]'
         else:
             return '[label="C"]'
+
+
+class InnerLink(InnerDependency):
+
+    def do_test(self, task, dependency_force=False):
+        self.parent.run(False, parent=task)
+        return False
+
+    def extra(self):
+        return '[label="L"]'
