@@ -1,5 +1,28 @@
 from subprocess import Popen, PIPE
-from pymk.error import CommandError
+from pymk.error import CommandError, CommandAborted
+
+_all_subprocesses = []
+_aborted = False
+
+
+def kill_process(spp):
+    try:
+        if spp.poll() == None:
+            spp.kill()
+    except OSError:
+        pass
+
+
+def on_sigterm(signum, frame):
+    global _aborted
+    _aborted = True
+    for spp in _all_subprocesses:
+        kill_process(spp)
+
+
+def init_signal_handling():
+    import signal
+    signal.signal(signal.SIGTERM, on_sigterm)
 
 
 def run_cmd(args, show_output=False):
@@ -17,23 +40,20 @@ def run_cmd(args, show_output=False):
 
     def wait_for_termination(spp, show_output):
         error = spp.wait()
+        if _aborted:
+            raise CommandAborted()
         if error != 0:
             if show_output:
                 raise CommandError(error, '')
             else:
                 raise CommandError(error, spp.stderr.read())
-
-    def kill_process(spp):
-        try:
-            if spp.poll() == None:
-                spp.kill()
-        except OSError:
-            pass
     #---------------------------------------------------------------------------
     args = make_args(args)
     spp = run_program(args, show_output)
+    _all_subprocesses.append(spp)
     try:
         wait_for_termination(spp, show_output)
     finally:
         kill_process(spp)
+        _all_subprocesses.remove(spp)
     return spp.stdout, spp.stderr
